<?php

namespace Drupal\bcubed;

use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Plugin\ConfigurableInterface;

/**
 * Defines an interface for event plugins.
 */
interface EventInterface extends PluginInspectionInterface, ConfigurableInterface {

  /**
   * Return the name of the event.
   *
   * @return string
   *   Event label.
   */
  public function getLabel();

  /**
   * Returns the library name.
   *
   * Returns the name of the library which generates
   * this event (null for generated events).
   *
   * @return string|null
   *   Library, in standard format - eg "modulename/libraryname".
   */
  public function getLibrary();

  /**
   * Returns name of JS event generated by the library.
   *
   * @return string
   *   JS event.
   */
  public function getEventName();

  /**
   * Settings form.
   *
   * @return array|null
   *   Render array of settings form.
   */
  public function settingsForm(array $form, FormStateInterface $form_state);

  /**
   * Returns bcubed dependencies.
   *
   * @return array|null
   *   BCubed plugin dependencies.
   */
  public function bcubedPluginDependencies();

}
